# psycho

Python project management automation using standard build tools.

## Status

This project is at the ideas stage.

## Overview

The goal of the project is to automate some common tasks without introducing
too many new tools. The currently support tools are:

* [pip](https://pypi.org/project/pip/)
* [build](https://pypi.org/project/build/)
* [twine](https://pypi.org/project/twine/)

Currently the following are supported.

```bash
psycho add pandas
psycho remove pandas
psycho build
psyhco publish
```
